from PIL import Image
from . import Wellcome
import argparse, os
import base64, sys
from io import BytesIO
args=argparse.ArgumentParser(prog=f"python3 -m {os.path.dirname(__file__).split('/')[-1]}", description='Wellcome Maker')
args.add_argument('--server',help='run as api', action='store_true')
args.add_argument('--pic',help='Picture: Path')
args.add_argument('--host', default='0.0.0.0', help='default: 0.0.0.0')
args.add_argument('--port', default=int(os.environ.get('PORT', 8000)), type=int,help=f'default: {os.environ.get("PORT", 8000)}')
args.add_argument('--capt',help= 'Caption: String')
args.add_argument('--out', help='output: Path')
args.add_argument('--base64', help='base64 output', action='store_true')
parser=args.parse_args()
try:
    if parser.server:
        from io import BytesIO
        from flask import Flask, request, Response
        import requests
        app = Flask(__name__)
        @app.route('/')
        def main():
            url = request.args.get('url')
            name = request.args.get('name')
            if name and url:
                try:
                    img=BytesIO()
                    Wellcome().create(BytesIO(requests.get(url).content), name).save(img, format='png')
                    r=Response(img.getvalue())
                    r.headers['Content-Type'] = 'image/png'
                    return r
                except Exception as e:
                    print(e)
                    return {}
            return {}
        app.run(host=parser.host, port=parser.port)
    elif parser.pic and parser.capt and (parser.out or parser.base64):
        x=Wellcome().create(parser.pic, parser.capt)
        if parser.base64:
            bit = BytesIO()
            x.save(bit, format='png')
            sys.stdout.write(base64.b64encode(bit.getvalue()).decode())
            sys.stdout.flush()
        else:
            x.save(parser.out)
            print(f'Saved: {parser.out}')
    else:
        os.system(f"python3 -m {os.path.dirname(__file__).split('/')[-1]} --help")
except Exception as e:
    print(e)
    os.system(f"python3 -m {os.path.dirname(__file__).split('/')[-1]} --help")


import os
from PIL import Image, ImageFont, ImageDraw
from io import BytesIO
from typing import Union

def circle(im:Image.Image)->Image.Image:
    if not im.mode == 'RGBA':
        im  = im.convert('RGBA')
    new = Image.new("L", im.size)
    draw = ImageDraw.Draw(new)
    draw.ellipse([(0,0), new.size], fill=255)
    im.putalpha(new)
    return im

class Wellcome:
    def __init__(self) -> None:
        self.image = Image.open(os.path.dirname(__file__)+'/T1.jpg').convert("RGBA")
        self.font = ImageFont.FreeTypeFont(os.path.dirname(__file__)+'/FreeSerifItalic.ttf', 200)

    def create(self, profile:Union[BytesIO, str], name: str)->Image.Image:
        created = circle(Image.open(profile)).resize((400, 400))
        self.image.paste(created, (760, 220), created.convert('RGBA'))
        text = self.cuttext(name)
        ImageDraw.Draw(self.image).text(((self.image.width/2)-(self.font.getsize(text)[0]/2), 610), text, font=self.font, stroke_width=7, stroke_fill=(0, 0, 0))
        return self.image

    def cuttext(self, text)->str:
        if self.font.getsize(text)[0] < 755:
            return text
        else:
            while(self.font.getsize(text)[0]>755):
                print(text)
                text = text[:-1]
            return text[:-1]+'..'


from setuptools import setup
from os import path
base_dir = path.abspath(path.dirname(__file__))
setup(
  name = 'wellcome',        
  packages = ['wellcome'],
  include_package_data=True,
  long_description=open(path.join(base_dir, "README.md"), encoding="utf-8").read(),
  long_description_content_type='text/markdown',
  version = '0.1',    
  license='MIT',     
  description = 'Wellcome card generator', 
  author = 'Krypton Byte',                  
  author_email = 'galaxyvplus6434@gmail.com',     
  url = 'https://github.com/krypton-byte/wellcome',      
  keywords = ['Wellcome', 'Card'], 
  install_requires=[           
          'pillow',
          'requests',
          'flask'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      
    'Intended Audience :: Developers',      
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',  
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)